@@ -17,10 +17,10 @@
 Includes custom exception types, useful constants and shared helpers.
 """
 
-from six.moves import http_client
+import http.client
 
 _SLEEP_RETRY_ERROR_MSG = (
-    u"At most one of `max_cumulative_retry` and `max_retries` " u"can be specified."
+    "At most one of `max_cumulative_retry` and `max_retries` " "can be specified."
 )
 
 UPLOAD_CHUNK_SIZE = 262144  # 256 * 1024
@@ -63,10 +63,10 @@ exceeds this limit, no more retries will occur.
 
 RETRYABLE = (
     TOO_MANY_REQUESTS,  # 429
-    http_client.INTERNAL_SERVER_ERROR,  # 500
-    http_client.BAD_GATEWAY,  # 502
-    http_client.SERVICE_UNAVAILABLE,  # 503
-    http_client.GATEWAY_TIMEOUT,  # 504
+    http.client.INTERNAL_SERVER_ERROR,  # 500
+    http.client.BAD_GATEWAY,  # 502
+    http.client.SERVICE_UNAVAILABLE,  # 503
+    http.client.GATEWAY_TIMEOUT,  # 504
 )
 """iterable: HTTP status codes that indicate a retryable error.
 
@@ -119,12 +119,16 @@ class RetryStrategy(object):
         max_cumulative_retry (Optional[float]): The maximum **total** amount of
             time to sleep during retry process.
         max_retries (Optional[int]): The number of retries to attempt.
+        initial_delay (Optional[float]): The initial delay. Default 1.0 second.
+        muiltiplier (Optional[float]): Exponent of the backoff. Default is 2.0.
 
     Attributes:
         max_sleep (float): Maximum amount of time allowed between requests.
         max_cumulative_retry (Optional[float]): Maximum total sleep time
             allowed during retry process.
         max_retries (Optional[int]): The number retries to attempt.
+        initial_delay (Optional[float]): The initial delay. Default 1.0 second.
+        muiltiplier (Optional[float]): Exponent of the backoff. Default is 2.0.
 
     Raises:
         ValueError: If both of ``max_cumulative_retry`` and ``max_retries``
@@ -132,7 +136,12 @@ class RetryStrategy(object):
     """
 
     def __init__(
-        self, max_sleep=MAX_SLEEP, max_cumulative_retry=None, max_retries=None
+        self,
+        max_sleep=MAX_SLEEP,
+        max_cumulative_retry=None,
+        max_retries=None,
+        initial_delay=1.0,
+        multiplier=2.0,
     ):
         if max_cumulative_retry is not None and max_retries is not None:
             raise ValueError(_SLEEP_RETRY_ERROR_MSG)
@@ -142,6 +151,8 @@ class RetryStrategy(object):
         self.max_sleep = max_sleep
         self.max_cumulative_retry = max_cumulative_retry
         self.max_retries = max_retries
+        self.initial_delay = initial_delay
+        self.multiplier = multiplier
 
     def retry_allowed(self, total_sleep, num_retries):
         """Check if another retry is allowed.
