@@ -22,7 +22,7 @@ from google.resumable_media import _helpers
 from google.resumable_media.requests import _request_helpers
 
 
-_CHECKSUM_MISMATCH = u"""\
+_CHECKSUM_MISMATCH = """\
 Checksum mismatch while downloading:
 
   {}
@@ -119,7 +119,7 @@ class Download(_request_helpers.RequestsMixin, _download.Download):
                 )
                 raise common.DataCorruption(response, msg)
 
-    def _consume(
+    def consume(
         self,
         transport,
         timeout=(
@@ -127,10 +127,10 @@ class Download(_request_helpers.RequestsMixin, _download.Download):
             _request_helpers._DEFAULT_READ_TIMEOUT,
         ),
     ):
-        """Consume the resource to be downloaded without any retries.
+        """Consume the resource to be downloaded.
 
-        This is intended to be called by :meth:`consume` so it can be
-        wrapped with error handling and retry strategy.
+        If a ``stream`` is attached to this download, then the downloaded
+        resource will be written to the stream.
 
         Args:
             transport (~requests.Session): A ``requests`` object which can
@@ -155,61 +155,26 @@ class Download(_request_helpers.RequestsMixin, _download.Download):
         method, url, payload, headers = self._prepare_request()
         # NOTE: We assume "payload is None" but pass it along anyway.
         request_kwargs = {
-            u"data": payload,
-            u"headers": headers,
-            u"timeout": timeout,
+            "data": payload,
+            "headers": headers,
+            "timeout": timeout,
         }
         if self._stream is not None:
-            request_kwargs[u"stream"] = True
+            request_kwargs["stream"] = True
 
-        result = transport.request(method, url, **request_kwargs)
+        # Wrap the request business logic in a function to be retried.
+        def retriable_request():
+            result = transport.request(method, url, **request_kwargs)
 
-        self._process_response(result)
+            self._process_response(result)
 
-        if self._stream is not None:
-            self._write_to_stream(result)
+            if self._stream is not None:
+                self._write_to_stream(result)
 
-        return result
+            return result
 
-    def consume(
-        self,
-        transport,
-        timeout=(
-            _request_helpers._DEFAULT_CONNECT_TIMEOUT,
-            _request_helpers._DEFAULT_READ_TIMEOUT,
-        ),
-    ):
-        """Consume the resource to be downloaded.
-
-        If a ``stream`` is attached to this download, then the downloaded
-        resource will be written to the stream.
-
-        This operation is retry-able based on the download HTTP response and
-        connection error type. Will retry until :meth:`~.RetryStrategy.retry_allowed`
-        (on the current``self._retry_strategy``) returns :data:`False`.
-
-        Args:
-            transport (~requests.Session): A ``requests`` object which can
-                make authenticated requests.
-            timeout (Optional[Union[float, Tuple[float, float]]]):
-                The number of seconds to wait for the server response.
-                Depending on the retry strategy, a request may be repeated
-                several times using the same timeout each time.
-
-                Can also be passed as a tuple (connect_timeout, read_timeout).
-                See :meth:`requests.Session.request` documentation for details.
-
-        Returns:
-            ~requests.Response: The HTTP response returned by ``transport``.
-
-        Raises:
-            ~google.resumable_media.common.DataCorruption: If the download's
-                checksum doesn't agree with server-computed checksum.
-            ValueError: If the current :class:`Download` has already
-                finished.
-        """
-        return self._consume_with_retries(
-            self._consume, transport=transport, timeout=timeout
+        return _helpers.wait_and_retry(
+            retriable_request, self._get_status_code, self._retry_strategy
         )
 
 
@@ -291,7 +256,7 @@ class RawDownload(_request_helpers.RawRequestsMixin, _download.Download):
                 )
                 raise common.DataCorruption(response, msg)
 
-    def _consume(
+    def consume(
         self,
         transport,
         timeout=(
@@ -299,10 +264,10 @@ class RawDownload(_request_helpers.RawRequestsMixin, _download.Download):
             _request_helpers._DEFAULT_READ_TIMEOUT,
         ),
     ):
-        """Consume the resource to be downloaded without any retries.
+        """Consume the resource to be downloaded.
 
-        This is intended to be called by :meth:`consume` so it can be
-        wrapped with error handling and retry strategy.
+        If a ``stream`` is attached to this download, then the downloaded
+        resource will be written to the stream.
 
         Args:
             transport (~requests.Session): A ``requests`` object which can
@@ -325,62 +290,28 @@ class RawDownload(_request_helpers.RawRequestsMixin, _download.Download):
                 finished.
         """
         method, url, payload, headers = self._prepare_request()
-        # NOTE: We assume "payload is None" but pass it along anyway.
-        result = transport.request(
-            method,
-            url,
-            data=payload,
-            headers=headers,
-            stream=True,
-            timeout=timeout,
-        )
 
-        self._process_response(result)
+        # Wrap the request business logic in a function to be retried.
+        def retriable_request():
+            # NOTE: We assume "payload is None" but pass it along anyway.
+            result = transport.request(
+                method,
+                url,
+                data=payload,
+                headers=headers,
+                stream=True,
+                timeout=timeout,
+            )
 
-        if self._stream is not None:
-            self._write_to_stream(result)
+            self._process_response(result)
 
-        return result
+            if self._stream is not None:
+                self._write_to_stream(result)
 
-    def consume(
-        self,
-        transport,
-        timeout=(
-            _request_helpers._DEFAULT_CONNECT_TIMEOUT,
-            _request_helpers._DEFAULT_READ_TIMEOUT,
-        ),
-    ):
-        """Consume the resource to be downloaded.
+            return result
 
-        If a ``stream`` is attached to this download, then the downloaded
-        resource will be written to the stream.
-
-        This operation is retry-able based on the download HTTP response and
-        connection error type. Will retry until :meth:`~.RetryStrategy.retry_allowed`
-        (on the current``self._retry_strategy``) returns :data:`False`.
-
-        Args:
-            transport (~requests.Session): A ``requests`` object which can
-                make authenticated requests.
-            timeout (Optional[Union[float, Tuple[float, float]]]):
-                The number of seconds to wait for the server response.
-                Depending on the retry strategy, a request may be repeated
-                several times using the same timeout each time.
-
-                Can also be passed as a tuple (connect_timeout, read_timeout).
-                See :meth:`requests.Session.request` documentation for details.
-
-        Returns:
-            ~requests.Response: The HTTP response returned by ``transport``.
-
-        Raises:
-            ~google.resumable_media.common.DataCorruption: If the download's
-                checksum doesn't agree with server-computed checksum.
-            ValueError: If the current :class:`Download` has already
-                finished.
-        """
-        return self._consume_with_retries(
-            self._consume, transport=transport, timeout=timeout
+        return _helpers.wait_and_retry(
+            retriable_request, self._get_status_code, self._retry_strategy
         )
 
 
@@ -412,7 +343,7 @@ class ChunkedDownload(_request_helpers.RequestsMixin, _download.ChunkedDownload)
         ValueError: If ``start`` is negative.
     """
 
-    def _consume_next_chunk(
+    def consume_next_chunk(
         self,
         transport,
         timeout=(
@@ -420,10 +351,7 @@ class ChunkedDownload(_request_helpers.RequestsMixin, _download.ChunkedDownload)
             _request_helpers._DEFAULT_READ_TIMEOUT,
         ),
     ):
-        """Consume the next chunk of the resource to be downloaded without any retries.
-
-        This is intended to be called by :meth:`consume_next_chunk` so it can be
-        wrapped with error handling and retry strategy.
+        """Consume the next chunk of the resource to be downloaded.
 
         Args:
             transport (~requests.Session): A ``requests`` object which can
@@ -443,47 +371,22 @@ class ChunkedDownload(_request_helpers.RequestsMixin, _download.ChunkedDownload)
             ValueError: If the current download has finished.
         """
         method, url, payload, headers = self._prepare_request()
-        # NOTE: We assume "payload is None" but pass it along anyway.
-        result = transport.request(
-            method,
-            url,
-            data=payload,
-            headers=headers,
-            timeout=timeout,
-        )
-        self._process_response(result)
-        return result
 
-    def consume_next_chunk(
-        self,
-        transport,
-        timeout=(
-            _request_helpers._DEFAULT_CONNECT_TIMEOUT,
-            _request_helpers._DEFAULT_READ_TIMEOUT,
-        ),
-    ):
-        """Consume the next chunk of the resource to be downloaded.
+        # Wrap the request business logic in a function to be retried.
+        def retriable_request():
+            # NOTE: We assume "payload is None" but pass it along anyway.
+            result = transport.request(
+                method,
+                url,
+                data=payload,
+                headers=headers,
+                timeout=timeout,
+            )
+            self._process_response(result)
+            return result
 
-        This operation is retry-able based on the download HTTP response and
-        connection error type. Will retry until :meth:`~.RetryStrategy.retry_allowed`
-        (on the current``self._retry_strategy``) returns :data:`False`.
-
-        Args:
-            transport (~requests.Session): A ``requests`` object which can
-                make authenticated requests.
-            timeout (Optional[Union[float, Tuple[float, float]]]):
-                The number of seconds to wait for the server response.
-                Depending on the retry strategy, a request may be repeated
-                several times using the same timeout each time.
-                Can also be passed as a tuple (connect_timeout, read_timeout).
-                See :meth:`requests.Session.request` documentation for details.
-        Returns:
-            ~requests.Response: The HTTP response returned by ``transport``.
-        Raises:
-            ValueError: If the current download has finished.
-        """
-        return self._consume_with_retries(
-            self._consume_next_chunk, transport=transport, timeout=timeout
+        return _helpers.wait_and_retry(
+            retriable_request, self._get_status_code, self._retry_strategy
         )
 
 
@@ -515,7 +418,7 @@ class RawChunkedDownload(_request_helpers.RawRequestsMixin, _download.ChunkedDow
         ValueError: If ``start`` is negative.
     """
 
-    def _consume_next_chunk(
+    def consume_next_chunk(
         self,
         transport,
         timeout=(
@@ -523,10 +426,7 @@ class RawChunkedDownload(_request_helpers.RawRequestsMixin, _download.ChunkedDow
             _request_helpers._DEFAULT_READ_TIMEOUT,
         ),
     ):
-        """Consume the next chunk of the resource to be downloaded without any retries.
-
-        This is intended to be called by :meth:`consume_next_chunk` so it can be
-        wrapped with error handling and retry strategy.
+        """Consume the next chunk of the resource to be downloaded.
 
         Args:
             transport (~requests.Session): A ``requests`` object which can
@@ -546,48 +446,23 @@ class RawChunkedDownload(_request_helpers.RawRequestsMixin, _download.ChunkedDow
             ValueError: If the current download has finished.
         """
         method, url, payload, headers = self._prepare_request()
-        # NOTE: We assume "payload is None" but pass it along anyway.
-        result = transport.request(
-            method,
-            url,
-            data=payload,
-            headers=headers,
-            stream=True,
-            timeout=timeout,
-        )
-        self._process_response(result)
-        return result
 
-    def consume_next_chunk(
-        self,
-        transport,
-        timeout=(
-            _request_helpers._DEFAULT_CONNECT_TIMEOUT,
-            _request_helpers._DEFAULT_READ_TIMEOUT,
-        ),
-    ):
-        """Consume the next chunk of the resource to be downloaded.
+        # Wrap the request business logic in a function to be retried.
+        def retriable_request():
+            # NOTE: We assume "payload is None" but pass it along anyway.
+            result = transport.request(
+                method,
+                url,
+                data=payload,
+                headers=headers,
+                stream=True,
+                timeout=timeout,
+            )
+            self._process_response(result)
+            return result
 
-        This operation is retry-able based on the download HTTP response and
-        connection error type. Will retry until :meth:`~.RetryStrategy.retry_allowed`
-        (on the current``self._retry_strategy``) returns :data:`False`.
-
-        Args:
-            transport (~requests.Session): A ``requests`` object which can
-                make authenticated requests.
-            timeout (Optional[Union[float, Tuple[float, float]]]):
-                The number of seconds to wait for the server response.
-                Depending on the retry strategy, a request may be repeated
-                several times using the same timeout each time.
-                Can also be passed as a tuple (connect_timeout, read_timeout).
-                See :meth:`requests.Session.request` documentation for details.
-        Returns:
-            ~requests.Response: The HTTP response returned by ``transport``.
-        Raises:
-            ValueError: If the current download has finished.
-        """
-        return self._consume_with_retries(
-            self._consume_next_chunk, transport=transport, timeout=timeout
+        return _helpers.wait_and_retry(
+            retriable_request, self._get_status_code, self._retry_strategy
         )
 
 
@@ -610,8 +485,8 @@ def _add_decoder(response_raw, checksum):
         patched, or a ``_DoNothingHash`` if the decoder is patched, since the
         caller will no longer need to hash to decoded bytes.
     """
-    encoding = response_raw.headers.get(u"content-encoding", u"").lower()
-    if encoding != u"gzip":
+    encoding = response_raw.headers.get("content-encoding", "").lower()
+    if encoding != "gzip":
         return checksum
 
     response_raw._decoder = _GzipDecoder(checksum)
