@@ -20,6 +20,7 @@ uploads that contain both metadata and a small file as payload.
 
 
 from google.resumable_media import _upload
+from google.resumable_media import _helpers
 from google.resumable_media.requests import _request_helpers
 
 
@@ -68,17 +69,20 @@ class SimpleUpload(_request_helpers.RequestsMixin, _upload.SimpleUpload):
             ~requests.Response: The HTTP response returned by ``transport``.
         """
         method, url, payload, headers = self._prepare_request(data, content_type)
-        response = _request_helpers.http_request(
-            transport,
-            method,
-            url,
-            data=payload,
-            headers=headers,
-            retry_strategy=self._retry_strategy,
-            timeout=timeout,
+
+        # Wrap the request business logic in a function to be retried.
+        def retriable_request():
+            result = transport.request(
+                method, url, data=payload, headers=headers, timeout=timeout
+            )
+
+            self._process_response(result)
+
+            return result
+
+        return _helpers.wait_and_retry(
+            retriable_request, self._get_status_code, self._retry_strategy
         )
-        self._process_response(response)
-        return response
 
 
 class MultipartUpload(_request_helpers.RequestsMixin, _upload.MultipartUpload):
@@ -136,18 +140,20 @@ class MultipartUpload(_request_helpers.RequestsMixin, _upload.MultipartUpload):
         method, url, payload, headers = self._prepare_request(
             data, metadata, content_type
         )
-        response = _request_helpers.http_request(
-            transport,
-            method,
-            url,
-            data=payload,
-            headers=headers,
-            retry_strategy=self._retry_strategy,
-            timeout=timeout,
-        )
 
-        self._process_response(response)
-        return response
+        # Wrap the request business logic in a function to be retried.
+        def retriable_request():
+            result = transport.request(
+                method, url, data=payload, headers=headers, timeout=timeout
+            )
+
+            self._process_response(result)
+
+            return result
+
+        return _helpers.wait_and_retry(
+            retriable_request, self._get_status_code, self._retry_strategy
+        )
 
 
 class ResumableUpload(_request_helpers.RequestsMixin, _upload.ResumableUpload):
@@ -163,15 +169,15 @@ class ResumableUpload(_request_helpers.RequestsMixin, _upload.ResumableUpload):
 
     .. testsetup:: resumable-constructor
 
-       bucket = u'bucket-foo'
+       bucket = 'bucket-foo'
 
     .. doctest:: resumable-constructor
 
        >>> from google.resumable_media.requests import ResumableUpload
        >>>
        >>> url_template = (
-       ...     u'https://www.googleapis.com/upload/storage/v1/b/{bucket}/o?'
-       ...     u'uploadType=resumable')
+       ...     'https://www.googleapis.com/upload/storage/v1/b/{bucket}/o?'
+       ...     'uploadType=resumable')
        >>> upload_url = url_template.format(bucket=bucket)
        >>>
        >>> chunk_size = 3 * 1024 * 1024  # 3MB
@@ -188,11 +194,11 @@ class ResumableUpload(_request_helpers.RequestsMixin, _upload.ResumableUpload):
 
        import mock
        import requests
-       from six.moves import http_client
+       import http.client
 
        from google.resumable_media.requests import ResumableUpload
 
-       upload_url = u'http://test.invalid'
+       upload_url = 'http://test.invalid'
        chunk_size = 3 * 1024 * 1024  # 3MB
        upload = ResumableUpload(upload_url, chunk_size)
 
@@ -200,14 +206,14 @@ class ResumableUpload(_request_helpers.RequestsMixin, _upload.ResumableUpload):
        os.close(file_desc)
 
        data = b'some bytes!'
-       with open(filename, u'wb') as file_obj:
+       with open(filename, 'wb') as file_obj:
            file_obj.write(data)
 
        fake_response = requests.Response()
-       fake_response.status_code = int(http_client.OK)
+       fake_response.status_code = int(http.client.OK)
        fake_response._content = b''
-       resumable_url = u'http://test.invalid?upload_id=7up'
-       fake_response.headers[u'location'] = resumable_url
+       resumable_url = 'http://test.invalid?upload_id=7up'
+       fake_response.headers['location'] = resumable_url
 
        post_method = mock.Mock(return_value=fake_response, spec=[])
        transport = mock.Mock(request=post_method, spec=['request'])
@@ -219,11 +225,11 @@ class ResumableUpload(_request_helpers.RequestsMixin, _upload.ResumableUpload):
        >>> upload.total_bytes is None
        True
        >>>
-       >>> stream = open(filename, u'rb')
+       >>> stream = open(filename, 'rb')
        >>> total_bytes = os.path.getsize(filename)
-       >>> metadata = {u'name': filename}
+       >>> metadata = {'name': filename}
        >>> response = upload.initiate(
-       ...     transport, stream, metadata, u'text/plain',
+       ...     transport, stream, metadata, 'text/plain',
        ...     total_bytes=total_bytes)
        >>> response
        <Response [200]>
@@ -245,26 +251,26 @@ class ResumableUpload(_request_helpers.RequestsMixin, _upload.ResumableUpload):
 
        import mock
        import requests
-       from six.moves import http_client
+       import http.client
 
        from google.resumable_media.requests import ResumableUpload
 
-       upload_url = u'http://test.invalid'
+       upload_url = 'http://test.invalid'
        chunk_size = 3 * 1024 * 1024  # 3MB
        upload = ResumableUpload(upload_url, chunk_size)
 
        fake_response = requests.Response()
-       fake_response.status_code = int(http_client.OK)
+       fake_response.status_code = int(http.client.OK)
        fake_response._content = b''
-       resumable_url = u'http://test.invalid?upload_id=7up'
-       fake_response.headers[u'location'] = resumable_url
+       resumable_url = 'http://test.invalid?upload_id=7up'
+       fake_response.headers['location'] = resumable_url
 
        post_method = mock.Mock(return_value=fake_response, spec=[])
        transport = mock.Mock(request=post_method, spec=['request'])
 
        data = b'some MOAR bytes!'
-       metadata = {u'name': u'some-file.jpg'}
-       content_type = u'image/jpeg'
+       metadata = {'name': 'some-file.jpg'}
+       content_type = 'image/jpeg'
 
     .. doctest:: resumable-implicit-size
 
@@ -286,25 +292,25 @@ class ResumableUpload(_request_helpers.RequestsMixin, _upload.ResumableUpload):
 
        import mock
        import requests
-       from six.moves import http_client
+       import http.client
 
        from google.resumable_media.requests import ResumableUpload
 
-       upload_url = u'http://test.invalid'
+       upload_url = 'http://test.invalid'
        chunk_size = 3 * 1024 * 1024  # 3MB
        upload = ResumableUpload(upload_url, chunk_size)
 
        fake_response = requests.Response()
-       fake_response.status_code = int(http_client.OK)
+       fake_response.status_code = int(http.client.OK)
        fake_response._content = b''
-       resumable_url = u'http://test.invalid?upload_id=7up'
-       fake_response.headers[u'location'] = resumable_url
+       resumable_url = 'http://test.invalid?upload_id=7up'
+       fake_response.headers['location'] = resumable_url
 
        post_method = mock.Mock(return_value=fake_response, spec=[])
        transport = mock.Mock(request=post_method, spec=['request'])
 
-       metadata = {u'name': u'some-file.jpg'}
-       content_type = u'application/octet-stream'
+       metadata = {'name': 'some-file.jpg'}
+       content_type = 'application/octet-stream'
 
        stream = io.BytesIO(b'data')
 
@@ -401,17 +407,20 @@ class ResumableUpload(_request_helpers.RequestsMixin, _upload.ResumableUpload):
             total_bytes=total_bytes,
             stream_final=stream_final,
         )
-        response = _request_helpers.http_request(
-            transport,
-            method,
-            url,
-            data=payload,
-            headers=headers,
-            retry_strategy=self._retry_strategy,
-            timeout=timeout,
+
+        # Wrap the request business logic in a function to be retried.
+        def retriable_request():
+            result = transport.request(
+                method, url, data=payload, headers=headers, timeout=timeout
+            )
+
+            self._process_initiate_response(result)
+
+            return result
+
+        return _helpers.wait_and_retry(
+            retriable_request, self._get_status_code, self._retry_strategy
         )
-        self._process_initiate_response(response)
-        return response
 
     def transmit_next_chunk(
         self,
@@ -437,24 +446,24 @@ class ResumableUpload(_request_helpers.RequestsMixin, _upload.ResumableUpload):
 
            import mock
            import requests
-           from six.moves import http_client
+           import http.client
 
            from google import resumable_media
            import google.resumable_media.requests.upload as upload_mod
 
            transport = mock.Mock(spec=['request'])
            fake_response = requests.Response()
-           fake_response.status_code = int(http_client.BAD_REQUEST)
+           fake_response.status_code = int(http.client.BAD_REQUEST)
            transport.request.return_value = fake_response
 
-           upload_url = u'http://test.invalid'
+           upload_url = 'http://test.invalid'
            upload = upload_mod.ResumableUpload(
                upload_url, resumable_media.UPLOAD_CHUNK_SIZE)
            # Fake that the upload has been initiate()-d
            data = b'data is here'
            upload._stream = io.BytesIO(data)
            upload._total_bytes = len(data)
-           upload._resumable_url = u'http://test.invalid?upload_id=nope'
+           upload._resumable_url = 'http://test.invalid?upload_id=nope'
 
         .. doctest:: bad-response
            :options: +NORMALIZE_WHITESPACE
@@ -493,17 +502,20 @@ class ResumableUpload(_request_helpers.RequestsMixin, _upload.ResumableUpload):
                 does not match or is not available.
         """
         method, url, payload, headers = self._prepare_request()
-        response = _request_helpers.http_request(
-            transport,
-            method,
-            url,
-            data=payload,
-            headers=headers,
-            retry_strategy=self._retry_strategy,
-            timeout=timeout,
+
+        # Wrap the request business logic in a function to be retried.
+        def retriable_request():
+            result = transport.request(
+                method, url, data=payload, headers=headers, timeout=timeout
+            )
+
+            self._process_response(result, len(payload))
+
+            return result
+
+        return _helpers.wait_and_retry(
+            retriable_request, self._get_status_code, self._retry_strategy
         )
-        self._process_response(response, len(payload))
-        return response
 
     def recover(self, transport):
         """Recover from a failure.
@@ -522,15 +534,24 @@ class ResumableUpload(_request_helpers.RequestsMixin, _upload.ResumableUpload):
         Returns:
             ~requests.Response: The HTTP response returned by ``transport``.
         """
+        timeout = (
+            _request_helpers._DEFAULT_CONNECT_TIMEOUT,
+            _request_helpers._DEFAULT_READ_TIMEOUT,
+        )
+
         method, url, payload, headers = self._prepare_recover_request()
         # NOTE: We assume "payload is None" but pass it along anyway.
-        response = _request_helpers.http_request(
-            transport,
-            method,
-            url,
-            data=payload,
-            headers=headers,
-            retry_strategy=self._retry_strategy,
+
+        # Wrap the request business logic in a function to be retried.
+        def retriable_request():
+            result = transport.request(
+                method, url, data=payload, headers=headers, timeout=timeout
+            )
+
+            self._process_recover_response(result)
+
+            return result
+
+        return _helpers.wait_and_retry(
+            retriable_request, self._get_status_code, self._retry_strategy
         )
-        self._process_recover_response(response)
-        return response
