@@ -12,31 +12,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import http.client
 import io
 import json
 
 import mock
-from six.moves import http_client
 
 from google import resumable_media
 import google.resumable_media.requests.upload as upload_mod
 
 
-SIMPLE_URL = (
-    u"https://www.googleapis.com/upload/storage/v1/b/{BUCKET}/o?"
-    u"uploadType=media&name={OBJECT}"
-)
-MULTIPART_URL = (
-    u"https://www.googleapis.com/upload/storage/v1/b/{BUCKET}/o?"
-    u"uploadType=multipart"
-)
-RESUMABLE_URL = (
-    u"https://www.googleapis.com/upload/storage/v1/b/{BUCKET}/o?"
-    u"uploadType=resumable"
-)
+URL_PREFIX = "https://www.googleapis.com/upload/storage/v1/b/{BUCKET}/o"
+SIMPLE_URL = URL_PREFIX + "?uploadType=media&name={OBJECT}"
+MULTIPART_URL = URL_PREFIX + "?uploadType=multipart"
+RESUMABLE_URL = URL_PREFIX + "?uploadType=resumable"
 ONE_MB = 1024 * 1024
-BASIC_CONTENT = u"text/plain"
-JSON_TYPE = u"application/json; charset=UTF-8"
+BASIC_CONTENT = "text/plain"
+JSON_TYPE = "application/json; charset=UTF-8"
 JSON_TYPE_LINE = b"content-type: application/json; charset=UTF-8\r\n"
 EXPECTED_TIMEOUT = (61, 60)
 
@@ -52,9 +44,9 @@ class TestSimpleUpload(object):
         assert not upload.finished
         ret_val = upload.transmit(transport, data, content_type)
         assert ret_val is transport.request.return_value
-        upload_headers = {u"content-type": content_type}
+        upload_headers = {"content-type": content_type}
         transport.request.assert_called_once_with(
-            u"POST",
+            "POST",
             SIMPLE_URL,
             data=data,
             headers=upload_headers,
@@ -71,9 +63,9 @@ class TestSimpleUpload(object):
 
         upload.transmit(transport, data, content_type, timeout=12.6)
 
-        expected_headers = {u"content-type": content_type}
+        expected_headers = {"content-type": content_type}
         transport.request.assert_called_once_with(
-            u"POST",
+            "POST",
             SIMPLE_URL,
             data=data,
             headers=expected_headers,
@@ -82,10 +74,10 @@ class TestSimpleUpload(object):
 
 
 class TestMultipartUpload(object):
-    @mock.patch(u"google.resumable_media._upload.get_boundary", return_value=b"==4==")
+    @mock.patch("google.resumable_media._upload.get_boundary", return_value=b"==4==")
     def test_transmit(self, mock_get_boundary):
         data = b"Mock data here and there."
-        metadata = {u"Hey": u"You", u"Guys": u"90909"}
+        metadata = {"Hey": "You", "Guys": "90909"}
         content_type = BASIC_CONTENT
         upload = upload_mod.MultipartUpload(MULTIPART_URL)
 
@@ -98,7 +90,7 @@ class TestMultipartUpload(object):
             b"--==4==\r\n"
             + JSON_TYPE_LINE
             + b"\r\n"
-            + json.dumps(metadata).encode(u"utf-8")
+            + json.dumps(metadata).encode("utf-8")
             + b"\r\n"
             + b"--==4==\r\n"
             b"content-type: text/plain\r\n"
@@ -107,9 +99,9 @@ class TestMultipartUpload(object):
             b"--==4==--"
         )
         multipart_type = b'multipart/related; boundary="==4=="'
-        upload_headers = {u"content-type": multipart_type}
+        upload_headers = {"content-type": multipart_type}
         transport.request.assert_called_once_with(
-            u"POST",
+            "POST",
             MULTIPART_URL,
             data=expected_payload,
             headers=upload_headers,
@@ -118,10 +110,10 @@ class TestMultipartUpload(object):
         assert upload.finished
         mock_get_boundary.assert_called_once_with()
 
-    @mock.patch(u"google.resumable_media._upload.get_boundary", return_value=b"==4==")
+    @mock.patch("google.resumable_media._upload.get_boundary", return_value=b"==4==")
     def test_transmit_w_custom_timeout(self, mock_get_boundary):
         data = b"Mock data here and there."
-        metadata = {u"Hey": u"You", u"Guys": u"90909"}
+        metadata = {"Hey": "You", "Guys": "90909"}
         content_type = BASIC_CONTENT
         upload = upload_mod.MultipartUpload(MULTIPART_URL)
         transport = mock.Mock(spec=["request"])
@@ -134,7 +126,7 @@ class TestMultipartUpload(object):
                 b"--==4==\r\n",
                 JSON_TYPE_LINE,
                 b"\r\n",
-                json.dumps(metadata).encode(u"utf-8"),
+                json.dumps(metadata).encode("utf-8"),
                 b"\r\n",
                 b"--==4==\r\n",
                 b"content-type: text/plain\r\n",
@@ -144,10 +136,10 @@ class TestMultipartUpload(object):
             )
         )
         multipart_type = b'multipart/related; boundary="==4=="'
-        upload_headers = {u"content-type": multipart_type}
+        upload_headers = {"content-type": multipart_type}
 
         transport.request.assert_called_once_with(
-            u"POST",
+            "POST",
             MULTIPART_URL,
             data=expected_payload,
             headers=upload_headers,
@@ -162,11 +154,11 @@ class TestResumableUpload(object):
         upload = upload_mod.ResumableUpload(RESUMABLE_URL, ONE_MB)
         data = b"Knock knock who is there"
         stream = io.BytesIO(data)
-        metadata = {u"name": u"got-jokes.txt"}
+        metadata = {"name": "got-jokes.txt"}
 
         transport = mock.Mock(spec=["request"])
-        location = (u"http://test.invalid?upload_id=AACODBBBxuw9u3AA",)
-        response_headers = {u"location": location}
+        location = ("http://test.invalid?upload_id=AACODBBBxuw9u3AA",)
+        response_headers = {"location": location}
         post_response = _make_response(headers=response_headers)
         transport.request.return_value = post_response
         # Check resumable_url before.
@@ -188,12 +180,12 @@ class TestResumableUpload(object):
         # Make sure the mock was called as expected.
         json_bytes = b'{"name": "got-jokes.txt"}'
         expected_headers = {
-            u"content-type": JSON_TYPE,
-            u"x-upload-content-type": BASIC_CONTENT,
-            u"x-upload-content-length": u"{:d}".format(total_bytes),
+            "content-type": JSON_TYPE,
+            "x-upload-content-type": BASIC_CONTENT,
+            "x-upload-content-length": "{:d}".format(total_bytes),
         }
         transport.request.assert_called_once_with(
-            u"POST",
+            "POST",
             RESUMABLE_URL,
             data=json_bytes,
             headers=expected_headers,
@@ -204,11 +196,11 @@ class TestResumableUpload(object):
         upload = upload_mod.ResumableUpload(RESUMABLE_URL, ONE_MB)
         data = b"Knock knock who is there"
         stream = io.BytesIO(data)
-        metadata = {u"name": u"got-jokes.txt"}
+        metadata = {"name": "got-jokes.txt"}
 
         transport = mock.Mock(spec=["request"])
-        location = (u"http://test.invalid?upload_id=AACODBBBxuw9u3AA",)
-        response_headers = {u"location": location}
+        location = ("http://test.invalid?upload_id=AACODBBBxuw9u3AA",)
+        response_headers = {"location": location}
         post_response = _make_response(headers=response_headers)
         transport.request.return_value = post_response
 
@@ -224,12 +216,12 @@ class TestResumableUpload(object):
         # Make sure timeout was passed to the transport
         json_bytes = b'{"name": "got-jokes.txt"}'
         expected_headers = {
-            u"content-type": JSON_TYPE,
-            u"x-upload-content-type": BASIC_CONTENT,
-            u"x-upload-content-length": u"{:d}".format(100),
+            "content-type": JSON_TYPE,
+            "x-upload-content-type": BASIC_CONTENT,
+            "x-upload-content-length": "{:d}".format(100),
         }
         transport.request.assert_called_once_with(
-            u"POST",
+            "POST",
             RESUMABLE_URL,
             data=json_bytes,
             headers=expected_headers,
@@ -242,7 +234,7 @@ class TestResumableUpload(object):
         upload._stream = io.BytesIO(data)
         upload._content_type = BASIC_CONTENT
         upload._total_bytes = len(data)
-        upload._resumable_url = u"http://test.invalid?upload_id=not-none"
+        upload._resumable_url = "http://test.invalid?upload_id=not-none"
         return upload
 
     @staticmethod
@@ -261,7 +253,7 @@ class TestResumableUpload(object):
         assert chunk_size < len(data)
         upload._chunk_size = chunk_size
         # Make a fake 308 response.
-        response_headers = {u"range": u"bytes=0-{:d}".format(chunk_size - 1)}
+        response_headers = {"range": "bytes=0-{:d}".format(chunk_size - 1)}
         transport = self._chunk_mock(
             resumable_media.PERMANENT_REDIRECT, response_headers
         )
@@ -275,13 +267,13 @@ class TestResumableUpload(object):
         assert upload._bytes_uploaded == chunk_size
         # Make sure the mock was called as expected.
         payload = data[:chunk_size]
-        content_range = u"bytes 0-{:d}/{:d}".format(chunk_size - 1, len(data))
+        content_range = "bytes 0-{:d}/{:d}".format(chunk_size - 1, len(data))
         expected_headers = {
-            u"content-range": content_range,
-            u"content-type": BASIC_CONTENT,
+            "content-range": content_range,
+            "content-type": BASIC_CONTENT,
         }
         transport.request.assert_called_once_with(
-            u"PUT",
+            "PUT",
             upload.resumable_url,
             data=payload,
             headers=expected_headers,
@@ -297,7 +289,7 @@ class TestResumableUpload(object):
         upload._chunk_size = chunk_size
 
         # Make a fake 308 response.
-        response_headers = {u"range": u"bytes=0-{:d}".format(chunk_size - 1)}
+        response_headers = {"range": "bytes=0-{:d}".format(chunk_size - 1)}
         transport = self._chunk_mock(
             resumable_media.PERMANENT_REDIRECT, response_headers
         )
@@ -307,13 +299,13 @@ class TestResumableUpload(object):
 
         # Make sure timeout was passed to the transport
         payload = data[:chunk_size]
-        content_range = u"bytes 0-{:d}/{:d}".format(chunk_size - 1, len(data))
+        content_range = "bytes 0-{:d}/{:d}".format(chunk_size - 1, len(data))
         expected_headers = {
-            u"content-range": content_range,
-            u"content-type": BASIC_CONTENT,
+            "content-range": content_range,
+            "content-type": BASIC_CONTENT,
         }
         transport.request.assert_called_once_with(
-            u"PUT",
+            "PUT",
             upload.resumable_url,
             data=payload,
             headers=expected_headers,
@@ -324,10 +316,10 @@ class TestResumableUpload(object):
         upload = upload_mod.ResumableUpload(RESUMABLE_URL, ONE_MB)
         upload._invalid = True  # Make sure invalid.
         upload._stream = mock.Mock(spec=["seek"])
-        upload._resumable_url = u"http://test.invalid?upload_id=big-deal"
+        upload._resumable_url = "http://test.invalid?upload_id=big-deal"
 
         end = 55555
-        headers = {u"range": u"bytes=0-{:d}".format(end)}
+        headers = {"range": "bytes=0-{:d}".format(end)}
         transport = self._chunk_mock(resumable_media.PERMANENT_REDIRECT, headers)
 
         ret_val = upload.recover(transport)
@@ -336,9 +328,9 @@ class TestResumableUpload(object):
         assert upload.bytes_uploaded == end + 1
         assert not upload.invalid
         upload._stream.seek.assert_called_once_with(end + 1)
-        expected_headers = {u"content-range": u"bytes */*"}
+        expected_headers = {"content-range": "bytes */*"}
         transport.request.assert_called_once_with(
-            u"PUT",
+            "PUT",
             upload.resumable_url,
             data=None,
             headers=expected_headers,
@@ -346,7 +338,7 @@ class TestResumableUpload(object):
         )
 
 
-def _make_response(status_code=http_client.OK, headers=None):
+def _make_response(status_code=http.client.OK, headers=None):
     headers = headers or {}
     return mock.Mock(
         headers=headers, status_code=status_code, spec=["headers", "status_code"]
