@@ -12,19 +12,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import http.client
 import io
 
 import mock
 import pytest
-from six.moves import http_client
 
 from google.resumable_media import _download
 from google.resumable_media import common
 
 
 EXAMPLE_URL = (
-    u"https://www.googleapis.com/download/storage/v1/b/"
-    u"{BUCKET}/o/{OBJECT}?alt=media"
+    "https://www.googleapis.com/download/storage/v1/b/{BUCKET}/o/{OBJECT}?alt=media"
 )
 
 
@@ -42,7 +41,7 @@ class TestDownloadBase(object):
     def test_constructor_explicit(self):
         start = 11
         end = 10001
-        headers = {u"foof": u"barf"}
+        headers = {"foof": "barf"}
         download = _download.DownloadBase(
             EXAMPLE_URL,
             stream=mock.sentinel.stream,
@@ -75,19 +74,19 @@ class TestDownloadBase(object):
         with pytest.raises(NotImplementedError) as exc_info:
             _download.DownloadBase._get_status_code(None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
     def test__get_headers(self):
         with pytest.raises(NotImplementedError) as exc_info:
             _download.DownloadBase._get_headers(None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
     def test__get_body(self):
         with pytest.raises(NotImplementedError) as exc_info:
             _download.DownloadBase._get_body(None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
 
 class TestDownload(object):
@@ -100,27 +99,27 @@ class TestDownload(object):
     def test__prepare_request(self):
         download1 = _download.Download(EXAMPLE_URL)
         method1, url1, payload1, headers1 = download1._prepare_request()
-        assert method1 == u"GET"
+        assert method1 == "GET"
         assert url1 == EXAMPLE_URL
         assert payload1 is None
         assert headers1 == {}
 
         download2 = _download.Download(EXAMPLE_URL, start=53)
         method2, url2, payload2, headers2 = download2._prepare_request()
-        assert method2 == u"GET"
+        assert method2 == "GET"
         assert url2 == EXAMPLE_URL
         assert payload2 is None
-        assert headers2 == {u"range": u"bytes=53-"}
+        assert headers2 == {"range": "bytes=53-"}
 
     def test__prepare_request_with_headers(self):
-        headers = {u"spoonge": u"borb"}
+        headers = {"spoonge": "borb"}
         download = _download.Download(EXAMPLE_URL, start=11, end=111, headers=headers)
         method, url, payload, new_headers = download._prepare_request()
-        assert method == u"GET"
+        assert method == "GET"
         assert url == EXAMPLE_URL
         assert payload is None
         assert new_headers is headers
-        assert headers == {u"range": u"bytes=11-111", u"spoonge": u"borb"}
+        assert headers == {"range": "bytes=11-111", "spoonge": "borb"}
 
     def test__process_response(self):
         download = _download.Download(EXAMPLE_URL)
@@ -128,7 +127,7 @@ class TestDownload(object):
 
         # Make sure **not finished** before.
         assert not download.finished
-        response = mock.Mock(status_code=int(http_client.OK), spec=["status_code"])
+        response = mock.Mock(status_code=int(http.client.OK), spec=["status_code"])
         ret_val = download._process_response(response)
         assert ret_val is None
         # Make sure **finished** after.
@@ -141,7 +140,7 @@ class TestDownload(object):
         # Make sure **not finished** before.
         assert not download.finished
         response = mock.Mock(
-            status_code=int(http_client.NOT_FOUND), spec=["status_code"]
+            status_code=int(http.client.NOT_FOUND), spec=["status_code"]
         )
         with pytest.raises(common.InvalidResponse) as exc_info:
             download._process_response(response)
@@ -150,8 +149,8 @@ class TestDownload(object):
         assert error.response is response
         assert len(error.args) == 5
         assert error.args[1] == response.status_code
-        assert error.args[3] == http_client.OK
-        assert error.args[4] == http_client.PARTIAL_CONTENT
+        assert error.args[3] == http.client.OK
+        assert error.args[4] == http.client.PARTIAL_CONTENT
         # Make sure **finished** even after a failure.
         assert download.finished
 
@@ -160,7 +159,7 @@ class TestDownload(object):
         with pytest.raises(NotImplementedError) as exc_info:
             download.consume(None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
 
 class TestChunkedDownload(object):
@@ -245,14 +244,14 @@ class TestChunkedDownload(object):
 
     @staticmethod
     def _response_content_range(start_byte, end_byte, total_bytes):
-        return u"bytes {:d}-{:d}/{:d}".format(start_byte, end_byte, total_bytes)
+        return "bytes {:d}-{:d}/{:d}".format(start_byte, end_byte, total_bytes)
 
     def _response_headers(self, start_byte, end_byte, total_bytes):
         content_length = end_byte - start_byte + 1
         resp_range = self._response_content_range(start_byte, end_byte, total_bytes)
         return {
-            u"content-length": u"{:d}".format(content_length),
-            u"content-range": resp_range,
+            "content-length": "{:d}".format(content_length),
+            "content-range": resp_range,
         }
 
     def _mock_response(
@@ -272,7 +271,7 @@ class TestChunkedDownload(object):
         with pytest.raises(ValueError) as exc_info:
             download._prepare_request()
 
-        assert exc_info.match(u"Download has finished.")
+        assert exc_info.match("Download has finished.")
 
     def test__prepare_request_invalid(self):
         download = _download.ChunkedDownload(EXAMPLE_URL, 64, None)
@@ -280,39 +279,39 @@ class TestChunkedDownload(object):
         with pytest.raises(ValueError) as exc_info:
             download._prepare_request()
 
-        assert exc_info.match(u"Download is invalid and cannot be re-used.")
+        assert exc_info.match("Download is invalid and cannot be re-used.")
 
     def test__prepare_request(self):
         chunk_size = 2048
         download1 = _download.ChunkedDownload(EXAMPLE_URL, chunk_size, None)
         method1, url1, payload1, headers1 = download1._prepare_request()
-        assert method1 == u"GET"
+        assert method1 == "GET"
         assert url1 == EXAMPLE_URL
         assert payload1 is None
-        assert headers1 == {u"range": u"bytes=0-2047"}
+        assert headers1 == {"range": "bytes=0-2047"}
 
         download2 = _download.ChunkedDownload(
             EXAMPLE_URL, chunk_size, None, start=19991
         )
         download2._total_bytes = 20101
         method2, url2, payload2, headers2 = download2._prepare_request()
-        assert method2 == u"GET"
+        assert method2 == "GET"
         assert url2 == EXAMPLE_URL
         assert payload2 is None
-        assert headers2 == {u"range": u"bytes=19991-20100"}
+        assert headers2 == {"range": "bytes=19991-20100"}
 
     def test__prepare_request_with_headers(self):
         chunk_size = 2048
-        headers = {u"patrizio": u"Starf-ish"}
+        headers = {"patrizio": "Starf-ish"}
         download = _download.ChunkedDownload(
             EXAMPLE_URL, chunk_size, None, headers=headers
         )
         method, url, payload, new_headers = download._prepare_request()
-        assert method == u"GET"
+        assert method == "GET"
         assert url == EXAMPLE_URL
         assert payload is None
         assert new_headers is headers
-        expected = {u"patrizio": u"Starf-ish", u"range": u"bytes=0-2047"}
+        expected = {"patrizio": "Starf-ish", "range": "bytes=0-2047"}
         assert headers == expected
 
     def test__make_invalid(self):
@@ -342,7 +341,7 @@ class TestChunkedDownload(object):
             already + chunk_size - 1,
             total_bytes,
             content=data,
-            status_code=int(http_client.PARTIAL_CONTENT),
+            status_code=int(http.client.PARTIAL_CONTENT),
         )
         download._process_response(response)
         # Check internal state after.
@@ -373,10 +372,10 @@ class TestChunkedDownload(object):
             already + chunk_size - 1,
             total_bytes,
             content=data,
-            status_code=int(http_client.PARTIAL_CONTENT),
+            status_code=int(http.client.PARTIAL_CONTENT),
         )
-        response.headers[u"transfer-encoding"] = "chunked"
-        del response.headers[u"content-length"]
+        response.headers["transfer-encoding"] = "chunked"
+        del response.headers["content-length"]
         download._process_response(response)
         # Check internal state after.
         assert not download.finished
@@ -398,7 +397,7 @@ class TestChunkedDownload(object):
         assert download.total_bytes is None
         # Actually call the method to update.
         response = self._mock_response(
-            0, total_bytes - 1, total_bytes, status_code=int(http_client.NOT_FOUND)
+            0, total_bytes - 1, total_bytes, status_code=int(http.client.NOT_FOUND)
         )
         with pytest.raises(common.InvalidResponse) as exc_info:
             download._process_response(response)
@@ -407,8 +406,8 @@ class TestChunkedDownload(object):
         assert error.response is response
         assert len(error.args) == 5
         assert error.args[1] == response.status_code
-        assert error.args[3] == http_client.OK
-        assert error.args[4] == http_client.PARTIAL_CONTENT
+        assert error.args[3] == http.client.OK
+        assert error.args[4] == http.client.PARTIAL_CONTENT
         # Check internal state after.
         assert not download.finished
         assert download.bytes_downloaded == 0
@@ -427,8 +426,8 @@ class TestChunkedDownload(object):
         assert not download.invalid
         # Actually call the method to update.
         response = mock.Mock(
-            headers={u"content-range": u"bytes 0-99/99"},
-            status_code=int(http_client.PARTIAL_CONTENT),
+            headers={"content-range": "bytes 0-99/99"},
+            status_code=int(http.client.PARTIAL_CONTENT),
             content=b"DEADBEEF",
             spec=["headers", "status_code", "content"],
         )
@@ -438,7 +437,7 @@ class TestChunkedDownload(object):
         error = exc_info.value
         assert error.response is response
         assert len(error.args) == 2
-        assert error.args[1] == u"content-length"
+        assert error.args[1] == "content-length"
         # Check internal state after.
         assert not download.finished
         assert download.bytes_downloaded == 0
@@ -457,13 +456,13 @@ class TestChunkedDownload(object):
         # Actually call the method to update.
         data = b"stuff"
         headers = {
-            u"content-length": u"{:d}".format(len(data)),
-            u"content-range": u"kites x-y/58",
+            "content-length": "{:d}".format(len(data)),
+            "content-range": "kites x-y/58",
         }
         response = mock.Mock(
             content=data,
             headers=headers,
-            status_code=int(http_client.PARTIAL_CONTENT),
+            status_code=int(http.client.PARTIAL_CONTENT),
             spec=["content", "headers", "status_code"],
         )
         with pytest.raises(common.InvalidResponse) as exc_info:
@@ -472,7 +471,7 @@ class TestChunkedDownload(object):
         error = exc_info.value
         assert error.response is response
         assert len(error.args) == 3
-        assert error.args[1] == headers[u"content-range"]
+        assert error.args[1] == headers["content-range"]
         # Check internal state after.
         assert not download.finished
         assert download.bytes_downloaded == 0
@@ -498,7 +497,7 @@ class TestChunkedDownload(object):
             chunk_size - 1,
             total_bytes,
             content=data,
-            status_code=int(http_client.PARTIAL_CONTENT),
+            status_code=int(http.client.PARTIAL_CONTENT),
         )
         with pytest.raises(common.InvalidResponse) as exc_info:
             download._process_response(response)
@@ -534,7 +533,7 @@ class TestChunkedDownload(object):
             total_bytes - 1,
             total_bytes,
             content=data,
-            status_code=int(http_client.OK),
+            status_code=int(http.client.OK),
         )
         download._process_response(response)
         # Check internal state after.
@@ -566,7 +565,7 @@ class TestChunkedDownload(object):
             end,
             8 * chunk_size,
             content=data,
-            status_code=int(http_client.PARTIAL_CONTENT),
+            status_code=int(http.client.PARTIAL_CONTENT),
         )
         download._process_response(response)
         # Check internal state after.
@@ -583,8 +582,8 @@ class TestChunkedDownload(object):
         _fix_up_virtual(download)
 
         content_range = _download._ZERO_CONTENT_RANGE_HEADER
-        headers = {u"content-range": content_range}
-        status_code = http_client.REQUESTED_RANGE_NOT_SATISFIABLE
+        headers = {"content-range": content_range}
+        status_code = http.client.REQUESTED_RANGE_NOT_SATISFIABLE
         response = mock.Mock(
             headers=headers, status_code=status_code, spec=["headers", "status_code"]
         )
@@ -599,7 +598,7 @@ class TestChunkedDownload(object):
         with pytest.raises(NotImplementedError) as exc_info:
             download.consume_next_chunk(None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
 
 class Test__add_bytes_range(object):
@@ -613,35 +612,35 @@ class Test__add_bytes_range(object):
         headers = {}
         ret_val = _download.add_bytes_range(17, 1997, headers)
         assert ret_val is None
-        assert headers == {u"range": u"bytes=17-1997"}
+        assert headers == {"range": "bytes=17-1997"}
 
     def test_end_only(self):
         headers = {}
         ret_val = _download.add_bytes_range(None, 909, headers)
         assert ret_val is None
-        assert headers == {u"range": u"bytes=0-909"}
+        assert headers == {"range": "bytes=0-909"}
 
     def test_start_only(self):
         headers = {}
         ret_val = _download.add_bytes_range(3735928559, None, headers)
         assert ret_val is None
-        assert headers == {u"range": u"bytes=3735928559-"}
+        assert headers == {"range": "bytes=3735928559-"}
 
     def test_start_as_offset(self):
         headers = {}
         ret_val = _download.add_bytes_range(-123454321, None, headers)
         assert ret_val is None
-        assert headers == {u"range": u"bytes=-123454321"}
+        assert headers == {"range": "bytes=-123454321"}
 
 
 class Test_get_range_info(object):
     @staticmethod
     def _make_response(content_range):
-        headers = {u"content-range": content_range}
+        headers = {"content-range": content_range}
         return mock.Mock(headers=headers, spec=["headers"])
 
     def _success_helper(self, **kwargs):
-        content_range = u"Bytes 7-11/42"
+        content_range = "Bytes 7-11/42"
         response = self._make_response(content_range)
         start_byte, end_byte, total_bytes = _download.get_range_info(
             response, _get_headers, **kwargs
@@ -659,7 +658,7 @@ class Test_get_range_info(object):
         callback.assert_not_called()
 
     def _failure_helper(self, **kwargs):
-        content_range = u"nope x-6/y"
+        content_range = "nope x-6/y"
         response = self._make_response(content_range)
         with pytest.raises(common.InvalidResponse) as exc_info:
             _download.get_range_info(response, _get_headers, **kwargs)
@@ -685,7 +684,7 @@ class Test_get_range_info(object):
         error = exc_info.value
         assert error.response is response
         assert len(error.args) == 2
-        assert error.args[1] == u"content-range"
+        assert error.args[1] == "content-range"
 
     def test_missing_header(self):
         self._missing_header_helper()
@@ -699,22 +698,22 @@ class Test_get_range_info(object):
 class Test__check_for_zero_content_range(object):
     @staticmethod
     def _make_response(content_range, status_code):
-        headers = {u"content-range": content_range}
+        headers = {"content-range": content_range}
         return mock.Mock(
             headers=headers, status_code=status_code, spec=["headers", "status_code"]
         )
 
     def test_status_code_416_and_test_content_range_zero_both(self):
         content_range = _download._ZERO_CONTENT_RANGE_HEADER
-        status_code = http_client.REQUESTED_RANGE_NOT_SATISFIABLE
+        status_code = http.client.REQUESTED_RANGE_NOT_SATISFIABLE
         response = self._make_response(content_range, status_code)
         assert _download._check_for_zero_content_range(
             response, _get_status_code, _get_headers
         )
 
     def test_status_code_416_only(self):
-        content_range = u"bytes 2-5/3"
-        status_code = http_client.REQUESTED_RANGE_NOT_SATISFIABLE
+        content_range = "bytes 2-5/3"
+        status_code = http.client.REQUESTED_RANGE_NOT_SATISFIABLE
         response = self._make_response(content_range, status_code)
         assert not _download._check_for_zero_content_range(
             response, _get_status_code, _get_headers
@@ -722,7 +721,7 @@ class Test__check_for_zero_content_range(object):
 
     def test_content_range_zero_only(self):
         content_range = _download._ZERO_CONTENT_RANGE_HEADER
-        status_code = http_client.OK
+        status_code = http.client.OK
         response = self._make_response(content_range, status_code)
         assert not _download._check_for_zero_content_range(
             response, _get_status_code, _get_headers
