@@ -12,12 +12,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import http.client
 import io
 import sys
 
 import mock
 import pytest
-from six.moves import http_client
 
 from google import resumable_media
 from google.resumable_media import _helpers
@@ -25,21 +25,13 @@ from google.resumable_media import _upload
 from google.resumable_media import common
 
 
-SIMPLE_URL = (
-    u"https://www.googleapis.com/upload/storage/v1/b/{BUCKET}/o?"
-    u"uploadType=media&name={OBJECT}"
-)
-MULTIPART_URL = (
-    u"https://www.googleapis.com/upload/storage/v1/b/{BUCKET}/o?"
-    u"uploadType=multipart"
-)
-RESUMABLE_URL = (
-    u"https://www.googleapis.com/upload/storage/v1/b/{BUCKET}/o?"
-    u"uploadType=resumable"
-)
+URL_PREFIX = "https://www.googleapis.com/upload/storage/v1/b/{BUCKET}/o"
+SIMPLE_URL = URL_PREFIX + "?uploadType=media&name={OBJECT}"
+MULTIPART_URL = URL_PREFIX + "?uploadType=multipart"
+RESUMABLE_URL = URL_PREFIX + "?uploadType=resumable"
 ONE_MB = 1024 * 1024
-BASIC_CONTENT = u"text/plain"
-JSON_TYPE = u"application/json; charset=UTF-8"
+BASIC_CONTENT = "text/plain"
+JSON_TYPE = "application/json; charset=UTF-8"
 JSON_TYPE_LINE = b"content-type: application/json; charset=UTF-8\r\n"
 
 
@@ -52,7 +44,7 @@ class TestUploadBase(object):
         _check_retry_strategy(upload)
 
     def test_constructor_explicit(self):
-        headers = {u"spin": u"doctors"}
+        headers = {"spin": "doctors"}
         upload = _upload.UploadBase(SIMPLE_URL, headers=headers)
         assert upload.upload_url == SIMPLE_URL
         assert upload._headers is headers
@@ -78,7 +70,7 @@ class TestUploadBase(object):
 
         # Make sure **not finished** before.
         assert not upload.finished
-        status_code = http_client.SERVICE_UNAVAILABLE
+        status_code = http.client.SERVICE_UNAVAILABLE
         response = _make_response(status_code=status_code)
         with pytest.raises(common.InvalidResponse) as exc_info:
             upload._process_response(response)
@@ -87,7 +79,7 @@ class TestUploadBase(object):
         assert error.response is response
         assert len(error.args) == 4
         assert error.args[1] == status_code
-        assert error.args[3] == http_client.OK
+        assert error.args[3] == http.client.OK
         # Make sure **finished** after (even in failure).
         assert upload.finished
 
@@ -107,19 +99,19 @@ class TestUploadBase(object):
         with pytest.raises(NotImplementedError) as exc_info:
             _upload.UploadBase._get_status_code(None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
     def test__get_headers(self):
         with pytest.raises(NotImplementedError) as exc_info:
             _upload.UploadBase._get_headers(None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
     def test__get_body(self):
         with pytest.raises(NotImplementedError) as exc_info:
             _upload.UploadBase._get_body(None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
 
 class TestSimpleUpload(object):
@@ -129,39 +121,39 @@ class TestSimpleUpload(object):
         with pytest.raises(ValueError) as exc_info:
             upload._prepare_request(b"", None)
 
-        exc_info.match(u"An upload can only be used once.")
+        exc_info.match("An upload can only be used once.")
 
     def test__prepare_request_non_bytes_data(self):
         upload = _upload.SimpleUpload(SIMPLE_URL)
         assert not upload.finished
         with pytest.raises(TypeError) as exc_info:
-            upload._prepare_request(u"", None)
+            upload._prepare_request("", None)
 
-        exc_info.match(u"must be bytes")
+        exc_info.match("must be bytes")
 
     def test__prepare_request(self):
         upload = _upload.SimpleUpload(SIMPLE_URL)
-        content_type = u"image/jpeg"
+        content_type = "image/jpeg"
         data = b"cheetos and eetos"
         method, url, payload, headers = upload._prepare_request(data, content_type)
 
-        assert method == u"POST"
+        assert method == "POST"
         assert url == SIMPLE_URL
         assert payload == data
-        assert headers == {u"content-type": content_type}
+        assert headers == {"content-type": content_type}
 
     def test__prepare_request_with_headers(self):
-        headers = {u"x-goog-cheetos": u"spicy"}
+        headers = {"x-goog-cheetos": "spicy"}
         upload = _upload.SimpleUpload(SIMPLE_URL, headers=headers)
-        content_type = u"image/jpeg"
+        content_type = "image/jpeg"
         data = b"some stuff"
         method, url, payload, new_headers = upload._prepare_request(data, content_type)
 
-        assert method == u"POST"
+        assert method == "POST"
         assert url == SIMPLE_URL
         assert payload == data
         assert new_headers is headers
-        expected = {u"content-type": content_type, u"x-goog-cheetos": u"spicy"}
+        expected = {"content-type": content_type, "x-goog-cheetos": "spicy"}
         assert headers == expected
 
     def test_transmit(self):
@@ -169,7 +161,7 @@ class TestSimpleUpload(object):
         with pytest.raises(NotImplementedError) as exc_info:
             upload.transmit(None, None, None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
 
 class TestMultipartUpload(object):
@@ -182,7 +174,7 @@ class TestMultipartUpload(object):
         _check_retry_strategy(upload)
 
     def test_constructor_explicit(self):
-        headers = {u"spin": u"doctors"}
+        headers = {"spin": "doctors"}
         upload = _upload.MultipartUpload(MULTIPART_URL, headers=headers, checksum="md5")
         assert upload.upload_url == MULTIPART_URL
         assert upload._headers is headers
@@ -197,12 +189,12 @@ class TestMultipartUpload(object):
             upload._prepare_request(b"Hi", {}, BASIC_CONTENT)
 
     def test__prepare_request_non_bytes_data(self):
-        data = u"Nope not bytes."
+        data = "Nope not bytes."
         upload = _upload.MultipartUpload(MULTIPART_URL)
         with pytest.raises(TypeError):
             upload._prepare_request(data, {}, BASIC_CONTENT)
 
-    @mock.patch(u"google.resumable_media._upload.get_boundary", return_value=b"==3==")
+    @mock.patch("google.resumable_media._upload.get_boundary", return_value=b"==3==")
     def _prepare_request_helper(
         self,
         mock_get_boundary,
@@ -220,19 +212,19 @@ class TestMultipartUpload(object):
             # This should be fully overwritten by the calculated checksum, so
             # the output should not change even if this is set.
             if checksum == "md5":
-                metadata = {u"md5Hash": u"ZZZZZZZZZZZZZZZZZZZZZZ=="}
+                metadata = {"md5Hash": "ZZZZZZZZZZZZZZZZZZZZZZ=="}
             else:
-                metadata = {u"crc32c": u"ZZZZZZ=="}
+                metadata = {"crc32c": "ZZZZZZ=="}
         else:
             # To simplify parsing the response, omit other test metadata if a
             # checksum is specified.
-            metadata = {u"Some": u"Stuff"} if not checksum else {}
+            metadata = {"Some": "Stuff"} if not checksum else {}
         content_type = BASIC_CONTENT
         method, url, payload, new_headers = upload._prepare_request(
             data, metadata, content_type
         )
 
-        assert method == u"POST"
+        assert method == "POST"
         assert url == MULTIPART_URL
 
         preamble = b"--==3==\r\n" + JSON_TYPE_LINE + b"\r\n"
@@ -264,16 +256,16 @@ class TestMultipartUpload(object):
 
     def test__prepare_request(self):
         headers, multipart_type = self._prepare_request_helper()
-        assert headers == {u"content-type": multipart_type}
+        assert headers == {"content-type": multipart_type}
 
     def test__prepare_request_with_headers(self):
-        headers = {u"best": u"shirt", u"worst": u"hat"}
+        headers = {"best": "shirt", "worst": "hat"}
         new_headers, multipart_type = self._prepare_request_helper(headers=headers)
         assert new_headers is headers
         expected_headers = {
-            u"best": u"shirt",
-            u"content-type": multipart_type,
-            u"worst": u"hat",
+            "best": "shirt",
+            "content-type": multipart_type,
+            "worst": "hat",
         }
         assert expected_headers == headers
 
@@ -287,7 +279,7 @@ class TestMultipartUpload(object):
             checksum=checksum, expected_checksum=checksums[checksum]
         )
         assert headers == {
-            u"content-type": multipart_type,
+            "content-type": multipart_type,
         }
 
     @pytest.mark.parametrize("checksum", ["md5", "crc32c"])
@@ -302,7 +294,7 @@ class TestMultipartUpload(object):
             test_overwrite=True,
         )
         assert headers == {
-            u"content-type": multipart_type,
+            "content-type": multipart_type,
         }
 
     def test_transmit(self):
@@ -310,7 +302,7 @@ class TestMultipartUpload(object):
         with pytest.raises(NotImplementedError) as exc_info:
             upload.transmit(None, None, None, None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
 
 class TestResumableUpload(object):
@@ -368,7 +360,7 @@ class TestResumableUpload(object):
         assert upload.resumable_url is None
 
         # Make sure we cannot set it on public @property.
-        new_url = u"http://test.invalid?upload_id=not-none"
+        new_url = "http://test.invalid?upload_id=not-none"
         with pytest.raises(AttributeError):
             upload.resumable_url = new_url
 
@@ -405,7 +397,7 @@ class TestResumableUpload(object):
     def _prepare_initiate_request_helper(self, upload_headers=None, **method_kwargs):
         data = b"some really big big data."
         stream = io.BytesIO(data)
-        metadata = {u"name": u"big-data-file.txt"}
+        metadata = {"name": "big-data-file.txt"}
 
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB, headers=upload_headers)
         orig_headers = upload._headers.copy()
@@ -421,14 +413,14 @@ class TestResumableUpload(object):
         # Make sure the ``upload``-s state was updated.
         assert upload._stream == stream
         assert upload._content_type == BASIC_CONTENT
-        if method_kwargs == {u"stream_final": False}:
+        if method_kwargs == {"stream_final": False}:
             assert upload._total_bytes is None
         else:
             assert upload._total_bytes == len(data)
         # Make sure headers are untouched.
         assert headers is not upload._headers
         assert upload._headers == orig_headers
-        assert method == u"POST"
+        assert method == "POST"
         assert url == upload.upload_url
         # Make sure the stream is still at the beginning.
         assert stream.tell() == 0
@@ -438,23 +430,23 @@ class TestResumableUpload(object):
     def test__prepare_initiate_request(self):
         data, headers = self._prepare_initiate_request_helper()
         expected_headers = {
-            u"content-type": JSON_TYPE,
-            u"x-upload-content-length": u"{:d}".format(len(data)),
-            u"x-upload-content-type": BASIC_CONTENT,
+            "content-type": JSON_TYPE,
+            "x-upload-content-length": "{:d}".format(len(data)),
+            "x-upload-content-type": BASIC_CONTENT,
         }
         assert headers == expected_headers
 
     def test__prepare_initiate_request_with_headers(self):
-        headers = {u"caviar": u"beluga", u"top": u"quark"}
+        headers = {"caviar": "beluga", "top": "quark"}
         data, new_headers = self._prepare_initiate_request_helper(
             upload_headers=headers
         )
         expected_headers = {
-            u"caviar": u"beluga",
-            u"content-type": JSON_TYPE,
-            u"top": u"quark",
-            u"x-upload-content-length": u"{:d}".format(len(data)),
-            u"x-upload-content-type": BASIC_CONTENT,
+            "caviar": "beluga",
+            "content-type": JSON_TYPE,
+            "top": "quark",
+            "x-upload-content-length": "{:d}".format(len(data)),
+            "x-upload-content-type": BASIC_CONTENT,
         }
         assert new_headers == expected_headers
 
@@ -463,24 +455,24 @@ class TestResumableUpload(object):
         data, headers = self._prepare_initiate_request_helper(total_bytes=total_bytes)
         assert len(data) == total_bytes
         expected_headers = {
-            u"content-type": u"application/json; charset=UTF-8",
-            u"x-upload-content-length": u"{:d}".format(total_bytes),
-            u"x-upload-content-type": BASIC_CONTENT,
+            "content-type": "application/json; charset=UTF-8",
+            "x-upload-content-length": "{:d}".format(total_bytes),
+            "x-upload-content-type": BASIC_CONTENT,
         }
         assert headers == expected_headers
 
     def test__prepare_initiate_request_unknown_size(self):
         _, headers = self._prepare_initiate_request_helper(stream_final=False)
         expected_headers = {
-            u"content-type": u"application/json; charset=UTF-8",
-            u"x-upload-content-type": BASIC_CONTENT,
+            "content-type": "application/json; charset=UTF-8",
+            "x-upload-content-type": BASIC_CONTENT,
         }
         assert headers == expected_headers
 
     def test__prepare_initiate_request_already_initiated(self):
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
         # Fake that the upload has been started.
-        upload._resumable_url = u"http://test.invalid?upload_id=definitely-started"
+        upload._resumable_url = "http://test.invalid?upload_id=definitely-started"
 
         with pytest.raises(ValueError):
             upload._prepare_initiate_request(io.BytesIO(), {}, BASIC_CONTENT)
@@ -516,7 +508,7 @@ class TestResumableUpload(object):
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
         _fix_up_virtual(upload)
 
-        headers = {u"location": u"http://test.invalid?upload_id=kmfeij3234"}
+        headers = {"location": "http://test.invalid?upload_id=kmfeij3234"}
         response = _make_response(headers=headers)
         # Check resumable_url before.
         assert upload._resumable_url is None
@@ -524,14 +516,14 @@ class TestResumableUpload(object):
         ret_val = upload._process_initiate_response(response)
         assert ret_val is None
         # Check resumable_url after.
-        assert upload._resumable_url == headers[u"location"]
+        assert upload._resumable_url == headers["location"]
 
     def test_initiate(self):
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
         with pytest.raises(NotImplementedError) as exc_info:
             upload.initiate(None, None, {}, BASIC_CONTENT)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
     def test__prepare_request_already_finished(self):
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
@@ -540,7 +532,7 @@ class TestResumableUpload(object):
         with pytest.raises(ValueError) as exc_info:
             upload._prepare_request()
 
-        assert exc_info.value.args == (u"Upload has finished.",)
+        assert exc_info.value.args == ("Upload has finished.",)
 
     def test__prepare_request_invalid(self):
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
@@ -549,8 +541,8 @@ class TestResumableUpload(object):
         with pytest.raises(ValueError) as exc_info:
             upload._prepare_request()
 
-        assert exc_info.match(u"invalid state")
-        assert exc_info.match(u"recover()")
+        assert exc_info.match("invalid state")
+        assert exc_info.match("recover()")
 
     def test__prepare_request_not_initiated(self):
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
@@ -560,21 +552,21 @@ class TestResumableUpload(object):
         with pytest.raises(ValueError) as exc_info:
             upload._prepare_request()
 
-        assert exc_info.match(u"upload has not been initiated")
-        assert exc_info.match(u"initiate()")
+        assert exc_info.match("upload has not been initiated")
+        assert exc_info.match("initiate()")
 
     def test__prepare_request_invalid_stream_state(self):
         stream = io.BytesIO(b"some data here")
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
         upload._stream = stream
-        upload._resumable_url = u"http://test.invalid?upload_id=not-none"
+        upload._resumable_url = "http://test.invalid?upload_id=not-none"
         # Make stream.tell() disagree with bytes_uploaded.
         upload._bytes_uploaded = 5
         assert upload.bytes_uploaded != stream.tell()
         with pytest.raises(ValueError) as exc_info:
             upload._prepare_request()
 
-        assert exc_info.match(u"Bytes stream is in unexpected state.")
+        assert exc_info.match("Bytes stream is in unexpected state.")
 
     @staticmethod
     def _upload_in_flight(data, headers=None, checksum=None):
@@ -584,7 +576,7 @@ class TestResumableUpload(object):
         upload._stream = io.BytesIO(data)
         upload._content_type = BASIC_CONTENT
         upload._total_bytes = len(data)
-        upload._resumable_url = u"http://test.invalid?upload_id=not-none"
+        upload._resumable_url = "http://test.invalid?upload_id=not-none"
         return upload
 
     def _prepare_request_helper(self, headers=None, checksum=None):
@@ -592,7 +584,7 @@ class TestResumableUpload(object):
         upload = self._upload_in_flight(data, headers=headers, checksum=checksum)
         method, url, payload, new_headers = upload._prepare_request()
         # Check the response values.
-        assert method == u"PUT"
+        assert method == "PUT"
         assert url == upload.resumable_url
         assert payload == data
         # Make sure headers are **NOT** updated
@@ -603,22 +595,22 @@ class TestResumableUpload(object):
     def test__prepare_request_success(self):
         headers = self._prepare_request_helper()
         expected_headers = {
-            u"content-range": u"bytes 0-32/33",
-            u"content-type": BASIC_CONTENT,
+            "content-range": "bytes 0-32/33",
+            "content-type": BASIC_CONTENT,
         }
         assert headers == expected_headers
 
     def test__prepare_request_success_with_headers(self):
-        headers = {u"cannot": u"touch this"}
+        headers = {"cannot": "touch this"}
         new_headers = self._prepare_request_helper(headers)
         assert new_headers is not headers
         expected_headers = {
-            u"content-range": u"bytes 0-32/33",
-            u"content-type": BASIC_CONTENT,
+            "content-range": "bytes 0-32/33",
+            "content-type": BASIC_CONTENT,
         }
         assert new_headers == expected_headers
         # Make sure the ``_headers`` are not incorporated.
-        assert u"cannot" not in new_headers
+        assert "cannot" not in new_headers
 
     @pytest.mark.parametrize("checksum", ["md5", "crc32c"])
     def test__prepare_request_with_checksum(self, checksum):
@@ -720,7 +712,7 @@ class TestResumableUpload(object):
 
         # Make sure the upload is valid before the failure.
         assert not upload.invalid
-        response = _make_response(status_code=http_client.NOT_FOUND)
+        response = _make_response(status_code=http.client.NOT_FOUND)
         with pytest.raises(common.InvalidResponse) as exc_info:
             upload._process_response(response, None)
 
@@ -728,7 +720,7 @@ class TestResumableUpload(object):
         assert error.response is response
         assert len(error.args) == 5
         assert error.args[1] == response.status_code
-        assert error.args[3] == http_client.OK
+        assert error.args[3] == http.client.OK
         assert error.args[4] == resumable_media.PERMANENT_REDIRECT
         # Make sure the upload is invalid after the failure.
         assert upload.invalid
@@ -745,11 +737,11 @@ class TestResumableUpload(object):
         # Set the response body.
         bytes_sent = 158
         total_bytes = upload._bytes_uploaded + bytes_sent
-        response_body = u'{{"size": "{:d}"}}'.format(total_bytes)
-        response_body = response_body.encode(u"utf-8")
+        response_body = '{{"size": "{:d}"}}'.format(total_bytes)
+        response_body = response_body.encode("utf-8")
         response = mock.Mock(
             content=response_body,
-            status_code=http_client.OK,
+            status_code=http.client.OK,
             spec=["content", "status_code"],
         )
         ret_val = upload._process_response(response, bytes_sent)
@@ -774,7 +766,7 @@ class TestResumableUpload(object):
         error = exc_info.value
         assert error.response is response
         assert len(error.args) == 2
-        assert error.args[1] == u"range"
+        assert error.args[1] == "range"
 
     def test__process_response_partial_bad_range(self):
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
@@ -782,7 +774,7 @@ class TestResumableUpload(object):
 
         # Make sure the upload is valid before the failure.
         assert not upload.invalid
-        headers = {u"range": u"nights 1-81"}
+        headers = {"range": "nights 1-81"}
         response = _make_response(
             status_code=resumable_media.PERMANENT_REDIRECT, headers=headers
         )
@@ -793,7 +785,7 @@ class TestResumableUpload(object):
         error = exc_info.value
         assert error.response is response
         assert len(error.args) == 3
-        assert error.args[1] == headers[u"range"]
+        assert error.args[1] == headers["range"]
         # Make sure the upload is invalid after the failure.
         assert upload.invalid
 
@@ -803,7 +795,7 @@ class TestResumableUpload(object):
 
         # Check status before.
         assert upload._bytes_uploaded == 0
-        headers = {u"range": u"bytes=0-171"}
+        headers = {"range": "bytes=0-171"}
         response = _make_response(
             status_code=resumable_media.PERMANENT_REDIRECT, headers=headers
         )
@@ -922,7 +914,7 @@ class TestResumableUpload(object):
         error = exc_info.value
         assert error.response is response
         message = error.args[0]
-        correct_checksums = {"crc32c": u"Qg8thA==", "md5": u"GRvfKbqr5klAOwLkxgIf8w=="}
+        correct_checksums = {"crc32c": "Qg8thA==", "md5": "GRvfKbqr5klAOwLkxgIf8w=="}
         metadata_key = _helpers._get_metadata_key(checksum)
         assert message == _upload._UPLOAD_CHECKSUM_MISMATCH_MESSAGE.format(
             checksum.upper(), correct_checksums[checksum], metadata[metadata_key]
@@ -933,7 +925,7 @@ class TestResumableUpload(object):
         with pytest.raises(NotImplementedError) as exc_info:
             upload.transmit_next_chunk(None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
     def test__prepare_recover_request_not_invalid(self):
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
@@ -947,27 +939,27 @@ class TestResumableUpload(object):
         upload._invalid = True
 
         method, url, payload, headers = upload._prepare_recover_request()
-        assert method == u"PUT"
+        assert method == "PUT"
         assert url == upload.resumable_url
         assert payload is None
-        assert headers == {u"content-range": u"bytes */*"}
+        assert headers == {"content-range": "bytes */*"}
         # Make sure headers are untouched.
         assert upload._headers == {}
 
     def test__prepare_recover_request_with_headers(self):
-        headers = {u"lake": u"ocean"}
+        headers = {"lake": "ocean"}
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB, headers=headers)
         upload._invalid = True
 
         method, url, payload, new_headers = upload._prepare_recover_request()
-        assert method == u"PUT"
+        assert method == "PUT"
         assert url == upload.resumable_url
         assert payload is None
-        assert new_headers == {u"content-range": u"bytes */*"}
+        assert new_headers == {"content-range": "bytes */*"}
         # Make sure the ``_headers`` are not incorporated.
-        assert u"lake" not in new_headers
+        assert "lake" not in new_headers
         # Make sure headers are untouched.
-        assert upload._headers == {u"lake": u"ocean"}
+        assert upload._headers == {"lake": "ocean"}
 
     def test__process_recover_response_bad_status(self):
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
@@ -975,7 +967,7 @@ class TestResumableUpload(object):
 
         upload._invalid = True
 
-        response = _make_response(status_code=http_client.BAD_REQUEST)
+        response = _make_response(status_code=http.client.BAD_REQUEST)
         with pytest.raises(common.InvalidResponse) as exc_info:
             upload._process_recover_response(response)
 
@@ -1012,7 +1004,7 @@ class TestResumableUpload(object):
         upload._stream = mock.Mock(spec=["seek"])
         upload._bytes_uploaded = mock.sentinel.not_zero
 
-        headers = {u"range": u"bites=9-11"}
+        headers = {"range": "bites=9-11"}
         response = _make_response(
             status_code=resumable_media.PERMANENT_REDIRECT, headers=headers
         )
@@ -1022,7 +1014,7 @@ class TestResumableUpload(object):
         error = exc_info.value
         assert error.response is response
         assert len(error.args) == 3
-        assert error.args[1] == headers[u"range"]
+        assert error.args[1] == headers["range"]
         # Check the state of ``upload`` after (untouched).
         assert upload.bytes_uploaded is mock.sentinel.not_zero
         assert upload.invalid
@@ -1038,7 +1030,7 @@ class TestResumableUpload(object):
         assert upload.bytes_uploaded != 0
 
         end = 11
-        headers = {u"range": u"bytes=0-{:d}".format(end)}
+        headers = {"range": "bytes=0-{:d}".format(end)}
         response = _make_response(
             status_code=resumable_media.PERMANENT_REDIRECT, headers=headers
         )
@@ -1054,10 +1046,10 @@ class TestResumableUpload(object):
         with pytest.raises(NotImplementedError) as exc_info:
             upload.recover(None)
 
-        exc_info.match(u"virtual")
+        exc_info.match("virtual")
 
 
-@mock.patch(u"random.randrange", return_value=1234567890123456789)
+@mock.patch("random.randrange", return_value=1234567890123456789)
 def test_get_boundary(mock_rand):
     result = _upload.get_boundary()
     assert result == b"===============1234567890123456789=="
@@ -1065,11 +1057,11 @@ def test_get_boundary(mock_rand):
 
 
 class Test_construct_multipart_request(object):
-    @mock.patch(u"google.resumable_media._upload.get_boundary", return_value=b"==1==")
+    @mock.patch("google.resumable_media._upload.get_boundary", return_value=b"==1==")
     def test_binary(self, mock_get_boundary):
         data = b"By nary day tuh"
-        metadata = {u"name": u"hi-file.bin"}
-        content_type = u"application/octet-stream"
+        metadata = {"name": "hi-file.bin"}
+        content_type = "application/octet-stream"
         payload, multipart_boundary = _upload.construct_multipart_request(
             data, metadata, content_type
         )
@@ -1087,12 +1079,12 @@ class Test_construct_multipart_request(object):
         assert payload == expected_payload
         mock_get_boundary.assert_called_once_with()
 
-    @mock.patch(u"google.resumable_media._upload.get_boundary", return_value=b"==2==")
+    @mock.patch("google.resumable_media._upload.get_boundary", return_value=b"==2==")
     def test_unicode(self, mock_get_boundary):
-        data_unicode = u"\N{snowman}"
+        data_unicode = "\N{snowman}"
         # construct_multipart_request( ASSUMES callers pass bytes.
-        data = data_unicode.encode(u"utf-8")
-        metadata = {u"name": u"snowman.txt"}
+        data = data_unicode.encode("utf-8")
+        metadata = {"name": "snowman.txt"}
         content_type = BASIC_CONTENT
         payload, multipart_boundary = _upload.construct_multipart_request(
             data, metadata, content_type
@@ -1137,7 +1129,7 @@ class Test_get_next_chunk(object):
         with pytest.raises(ValueError) as exc_info:
             _upload.get_next_chunk(stream, 1, len(data))
 
-        exc_info.match(u"Stream is already exhausted. There is no content remaining.")
+        exc_info.match("Stream is already exhausted. There is no content remaining.")
 
     def test_exhausted_known_size_zero(self):
         stream = io.BytesIO(b"")
@@ -1148,7 +1140,7 @@ class Test_get_next_chunk(object):
         stream = io.BytesIO(b"not empty WAT!")
         with pytest.raises(ValueError) as exc_info:
             _upload.get_next_chunk(stream, 1, 0)
-        exc_info.match(u"Stream specified as empty, but produced non-empty content.")
+        exc_info.match("Stream specified as empty, but produced non-empty content.")
 
     def test_success_known_size_lt_stream_size(self):
         data = b"0123456789"
@@ -1161,9 +1153,9 @@ class Test_get_next_chunk(object):
         result1 = _upload.get_next_chunk(stream, chunk_size, total_bytes)
         result2 = _upload.get_next_chunk(stream, chunk_size, total_bytes)
 
-        assert result0 == (0, b"012", u"bytes 0-2/8")
-        assert result1 == (3, b"345", u"bytes 3-5/8")
-        assert result2 == (6, b"67", u"bytes 6-7/8")
+        assert result0 == (0, b"012", "bytes 0-2/8")
+        assert result1 == (3, b"345", "bytes 3-5/8")
+        assert result2 == (6, b"67", "bytes 6-7/8")
 
     def test_success_known_size(self):
         data = b"0123456789"
@@ -1175,10 +1167,10 @@ class Test_get_next_chunk(object):
         result1 = _upload.get_next_chunk(stream, chunk_size, total_bytes)
         result2 = _upload.get_next_chunk(stream, chunk_size, total_bytes)
         result3 = _upload.get_next_chunk(stream, chunk_size, total_bytes)
-        assert result0 == (0, b"012", u"bytes 0-2/10")
-        assert result1 == (3, b"345", u"bytes 3-5/10")
-        assert result2 == (6, b"678", u"bytes 6-8/10")
-        assert result3 == (9, b"9", u"bytes 9-9/10")
+        assert result0 == (0, b"012", "bytes 0-2/10")
+        assert result1 == (3, b"345", "bytes 3-5/10")
+        assert result2 == (6, b"678", "bytes 6-8/10")
+        assert result3 == (9, b"9", "bytes 9-9/10")
         assert stream.tell() == total_bytes
 
     def test_success_unknown_size(self):
@@ -1188,8 +1180,8 @@ class Test_get_next_chunk(object):
         # Splits into 4 chunks: abcdef, ghij
         result0 = _upload.get_next_chunk(stream, chunk_size, None)
         result1 = _upload.get_next_chunk(stream, chunk_size, None)
-        assert result0 == (0, b"abcdef", u"bytes 0-5/*")
-        assert result1 == (chunk_size, b"ghij", u"bytes 6-9/10")
+        assert result0 == (0, b"abcdef", "bytes 0-5/*")
+        assert result1 == (chunk_size, b"ghij", "bytes 6-9/10")
         assert stream.tell() == len(data)
 
         # Do the same when the chunk size evenly divides len(data)
@@ -1198,22 +1190,22 @@ class Test_get_next_chunk(object):
         # Splits into 2 chunks: `data` and empty string
         result0 = _upload.get_next_chunk(stream, chunk_size, None)
         result1 = _upload.get_next_chunk(stream, chunk_size, None)
-        assert result0 == (0, data, u"bytes 0-9/*")
-        assert result1 == (len(data), b"", u"bytes */10")
+        assert result0 == (0, data, "bytes 0-9/*")
+        assert result1 == (len(data), b"", "bytes */10")
         assert stream.tell() == len(data)
 
 
 class Test_get_content_range(object):
     def test_known_size(self):
         result = _upload.get_content_range(5, 10, 40)
-        assert result == u"bytes 5-10/40"
+        assert result == "bytes 5-10/40"
 
     def test_unknown_size(self):
         result = _upload.get_content_range(1000, 10000, None)
-        assert result == u"bytes 1000-10000/*"
+        assert result == "bytes 1000-10000/*"
 
 
-def _make_response(status_code=http_client.OK, headers=None, metadata=None):
+def _make_response(status_code=http.client.OK, headers=None, metadata=None):
     headers = headers or {}
     return mock.Mock(
         headers=headers,
